;///////////////////////////////////////////////////////////////////////////////////////////////////
;/							   Complete System Manager version 1.0	   							   /
;/								Written by Donald Straney 7/03/03								   /
;/						Designed for the Z80/TI-86 graphing calculator							   /
;///////////////////////////////////////////////////////////////////////////////////////////////////

;///////////////////////////////////////DEFINITIONS/////////////////////////////////////////////////

#include "ti86asm.inc"
#include "Rom86.h"
#include "Ram86.inc"

;CONSTANTS

Main_Menu_Pos_1	equ		$0b02		;Cursor positions for main menu text	
Main_Menu_Pos_2	equ		$1102
Main_Menu_Pos_3	equ		$1702
Main_Menu_Pos_4	equ 	$1d02
Main_Menu_Pos_5	equ		$2302
Main_Menu_Pos_6	equ		$2902

Submenu_Pos_1	equ		$0b32		;Cursor positions for submenu text
Submenu_Pos_2	equ		$1132
Submenu_Pos_3	equ		$1732
Submenu_Pos_4	equ		$1d32
Submenu_Pos_5	equ		$2332
Submenu_Pos_6	equ		$2932
Submenu_Pos_7	equ		$2f32
Submenu_Pos_8	equ		$3532

Home_1_Text_End	equ		$0b52		;End of text in menu items
Home_2_Text_End	equ		$1159
Home_3_Text_End	equ		$1763
Home_4_Text_End	equ		$1d5f
Home_5_Text_End	equ		$2362
Home_7_Text_End	equ		$2f4c

Graph_1_Text_End	equ	$0b62
Graph_2_Text_End	equ	$1153
Graph_3_Text_End	equ	$175c
Graph_4_Text_End	equ	$1d44
Graph_5_Text_End	equ	$235d
Graph_6_Text_End	equ	$2944
Graph_7_Text_End	equ	$2f4b
Graph_8_Text_End	equ	$3564

Text_1_Text_End	equ		$1157
Text_2_Text_End	equ		$1754
Text_3_Text_End	equ		$1d59
Text_4_Text_End	equ		$296f

User_1_Text_End	equ		$0b67
User_2_Text_End	equ		$1167
User_3_Text_End	equ		$176f
User_4_Text_End	equ		$1d57
User_5_Text_End	equ		$2359
User_6_Text_End	equ		$295d
User_7_Text_End	equ		$2f4c
User_8_Text_End	equ		$354b
User_9_Text_End	equ		$0b49
User_10_Text_End	equ	$1149
User_11_Text_End	equ	$174b
User_12_Text_End	equ	$1d53
User_13_Text_End	equ	$2346
User_14_Text_End	equ	$2945

Misc_1_Text_End	equ		$0b61
Misc_2_Text_End	equ		$116e
Misc_3_Text_End	equ		$1752

;/////////////////////////////////////////START OF PROGRAM//////////////////////////////////////////

.org _asm_exec_ram

	nop
	jp ProgStart

	.dw 0,ShellTitle

ShellTitle: .db "Complete System Manager",0

ProgStart:
	call _runindicoff					;Turn off that idiotic run indicator
	call Redraw_Window					;Draw window

Select_Memory:							;Select memory submenu
	ld a,8
	ld (_winBtm),a						;Prevent $3d0a from displaying number, set to clear whole screen
	inc a
	ld (_curRow),a
	call Redraw_Main_Menu				;Unselect any other previous menus
	call Clear_Submenu_Text				;Clear submenu text window
	ld hl,Main_Menu_Pos_1				;Invert text for menu item-first set cursor position
	ld (_penCol),hl
	set textInverse,(iy+textflags)		;Set for inverse text draw
	ld hl,Main_Menu_Text_1				;and draw over current main menu item
	call _vputs
	res textInverse,(iy+textflags)		;Set for normal text draw
	ld hl,Submenu_Pos_1					;Set cursor position for drawing submenu
	ld (_penCol),hl
	ld hl,Memory_Text_1					;Set text
	call _vputs							;and draw
	ld hl,Submenu_Pos_2
	ld (_penCol),hl
	ld hl,Memory_Text_2
	call _vputs
	call _memchk						;Display used memory-first get free mem
	call $3d0a							;Format it as displayable string in OP1
	ld hl,_OP2							;then format it as fp number into OP2
	ld (hl),0							;First, add fp number header
	inc hl
	ld (hl),$04
	inc hl
	ld (hl),$fc
	inc hl
	ld de,_OP1							;then format
	ld b,3
Format_Num_Loop:						;Convert from 1-byte ASCII digit to 1-nibble BCD digit
	ld a,(de)
	and $0f
	call _shlacc
	ld (hl),a
	inc de
	ld a,(de)
	and $0f
	or (hl)
	ld (hl),a
	inc hl
	inc de
	djnz Format_Num_Loop

	ld a,$30
	ld (de),a							;Make sure that last number is zero
	ld hl,Num_98226						;Subtract it from 98226 (total mem) to get used mem
	call _mov10toop1
	call _FPSUB
	ld a,5
	call _formReal						;Format back to displayable string
	ld b,5								;and display
	ld hl,_OP3
	call _vputsn
	ld hl,Submenu_Pos_3
	ld (_penCol),hl
	ld hl,Memory_Text_3
	call _vputs
	call _memchk
	call Display_AHL
	xor a								;Return cursor row to actual screen coordinates
	ld (_curRow),a
Memory_Key_Loop:
	call _getkey						;Wait for keypress
	cp kExit							;If it's exit, return
	ret z
	cp kLog								;Is it the log key?
	jr z,Select_Home					;If it is, select the homescreen submenu
	jr Memory_Key_Loop					;If none of these, wait for another key

Select_Home:							;Select homescreen submenu
	call Redraw_Main_Menu				;Unselect any other previous menus
	call Clear_Submenu_Text				;Clear submenu text window
	ld hl,Main_Menu_Pos_2				;Invert text for menu item-first set cursor position
	ld (_penCol),hl
	set textInverse,(iy+textflags)		;Set for inverse text draw
	ld hl,Main_Menu_Text_2				;and draw over current main menu item
	call _vputs
	res textInverse,(iy+textflags)		;Set for normal text draw

Home_1_Handler:							;Routine for selecting first menu item on homescreen submenu
	call Redraw_Home					;Deselect previously selected items
	ld hl,Submenu_Pos_1					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Home_Text_1
	call _vputs
	res textInverse,(iy+textflags)
Home_1_Refresh:
	ld hl,Home_1_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	ld a,(iy+fmtflags)					;Get format flags
	and %00000011						;Mask to get notation flags
	or a								;If is normal notation, draw that
	jr z,Home_1_Draw_Norm
	cp %00000001						;If is scientific notation, draw that
	jr z,Home_1_Draw_Sci
Home_1_Draw_Eng:						;Otherwise, show that is in engineering mode
	ld hl,Text_Eng						;Set text to be drawn
	jr Home_1_Draw
Home_1_Draw_Norm:
	ld hl,Text_Norm						;Set text to be drawn
	jr Home_1_Draw
Home_1_Draw_Sci:
	ld hl,Text_Sci						;Set text to be drawn
Home_1_Draw:
	call _vputs							;Now draw
Home_1_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,Home_1_R
	cp kLeft							;Is left key?
	jr z,Home_1_L
	cp kLog								;Is log key?
	jp z,Select_Graph
	cp kGrMenu							;Is graph key?
	jp z,Select_Memory
	cp kDown							;Is down key?
	jr z,Home_2_Handler
	cp kExit							;Is exit key?
	ret z
	jr Home_1_Key_Loop
Home_1_L:
	ld a,(iy+fmtflags)
	and %00000011
	or a
	jr z,Home_1_Select_Eng
	cp %00000001
	jr z,Home_1_Select_Norm
	jr Home_1_Select_Sci
Home_1_R:
	ld a,(iy+fmtflags)
	and %00000011
	or a
	jr z,Home_1_Select_Sci
	cp %00000001
	jr z,Home_1_Select_Eng
Home_1_Select_Norm:
	res fmtExponent,(iy+fmtflags)
	res fmtEng,(iy+fmtflags)
	jr Home_1_Refresh
Home_1_Select_Sci:
	set fmtExponent,(iy+fmtflags)
	res fmtEng,(iy+fmtflags)
	jr Home_1_Refresh
Home_1_Select_Eng:
	set fmtExponent,(iy+fmtflags)
	set fmtEng,(iy+fmtflags)
	jr Home_1_Refresh

Home_2_Handler:							;Routine for selecting second menu item on homescreen submenu
	call Redraw_Home					;Deselect previously selected items
	ld hl,Submenu_Pos_2					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Home_Text_2
	call _vputs
	res textInverse,(iy+textflags)
Home_2_Refresh:
	ld hl,Home_2_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit trigdeg,(iy+trigflags)
	jr z,Home_2_Draw_Rad				;If in radians mode, draw that
Home_2_Draw_Deg:						;Otherwise, show that is in degrees mode
	ld hl,Text_Deg						;Set text to be drawn
	jr Home_2_Draw
Home_2_Draw_Rad:
	ld hl,Text_Rad						;Set text to be drawn
Home_2_Draw:
	call _vputs							;Now draw
Home_2_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,Home_2_R
	cp kLeft							;Is left key?
	jr z,Home_2_R
	cp kLog								;Is log key?
	jp z,Select_Graph
	cp kGrMenu							;Is graph key?
	jp z,Select_Memory
	cp kUp								;Is up key?
	jp z,Home_1_Handler
	cp kDown							;Is down key?
	jp z,Home_3_Handler
	cp kExit							;Is exit key?
	ret z
	jr Home_2_Key_Loop
Home_2_R:
	bit trigdeg,(iy+trigflags)
	jr nz,Home_2_Select_Rad
Home_2_Select_Deg:
	set trigdeg,(iy+trigflags)
	jr Home_2_Refresh
Home_2_Select_Rad:
	res trigdeg,(iy+trigflags)
	jr Home_2_Refresh

Home_3_Handler:							;Routine for selecting third menu item on homescreen submenu
	call Redraw_Home					;Deselect previously selected items
	ld hl,Submenu_Pos_3					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Home_Text_3
	call _vputs
	res textInverse,(iy+textflags)
Home_3_Refresh:
	ld hl,Home_3_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 2,(iy+10)
	jr nz,Home_3_Draw_Hex				;If in hex mode, draw that
	bit 3,(iy+10)
	jr nz,Home_3_Draw_Oct				;If in octal mode, draw that
	bit 4,(iy+10)
	jr nz,Home_3_Draw_Bin				;If in binary mode, draw that
Home_3_Draw_Dec:						;Otherwise, show that is in decimal mode
	ld hl,Text_Dec						;Set text to be drawn
	jr Home_3_Draw
Home_3_Draw_Bin:
	ld hl,Text_Bin						;Set text to be drawn
	jr Home_3_Draw
Home_3_Draw_Hex:
	ld hl,Text_Hex						;Set text to be drawn
	jr Home_3_Draw
Home_3_Draw_Oct:
	ld hl,Text_Oct						;Set text to be drawn
Home_3_Draw:
	call _vputs							;Now draw
Home_3_Key_Loop:
	call _getkey 
	cp kRight							;Is right key?
	jr z,Home_3_R
	cp kLeft							;Is left key?
	jr z,Home_3_L
	cp kLog								;Is log key?
	jp z,Select_Graph
	cp kGrMenu							;Is graph key?
	jp z,Select_Memory
	cp kUp								;Is up key?
	jp z,Home_2_Handler
	cp kDown							;Is down key?
	jp z,Home_4_Handler
	cp kExit							;Is exit key?
	ret z
	jr Home_3_Key_Loop
Home_3_R:
	bit 2,(iy+10)
	jr nz,Home_3_Select_Bin
	bit 3,(iy+10)
	jr nz,Home_3_Select_Dec
	bit 4,(iy+10)
	jr nz,Home_3_Select_Oct
	jr Home_3_Select_Hex
Home_3_L:
	bit 2,(iy+10)
	jr nz,Home_3_Select_Dec
	bit 3,(iy+10)
	jr nz,Home_3_Select_Bin
	bit 4,(iy+10)
	jr nz,Home_3_Select_Hex
Home_3_Select_Oct:
	res 2,(iy+10)
	set 3,(iy+10)
	res 4,(iy+10)
	ld a,(iy+10)
	ld (iy+11),a
	jp Home_3_Refresh
Home_3_Select_Hex:
	set 2,(iy+10)
	res 3,(iy+10)
	res 4,(iy+10)
	ld a,(iy+10)
	ld (iy+11),a
	jp Home_3_Refresh
Home_3_Select_Bin:
	res 2,(iy+10)
	res 3,(iy+10)
	set 4,(iy+10)
	ld a,(iy+10)
	ld (iy+11),a
	jp Home_3_Refresh
Home_3_Select_Dec:
	res 2,(iy+10)
	res 3,(iy+10)
	res 4,(iy+10)
	ld a,(iy+10)
	ld (iy+11),a
	jp Home_3_Refresh

Home_4_Handler:							;Routine for selecting fourth menu item on homescreen submenu
	call Redraw_Home					;Deselect previously selected items
	ld hl,Submenu_Pos_4					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Home_Text_4
	call _vputs
	res textInverse,(iy+textflags)
Home_4_Refresh:
	ld hl,Home_4_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 7,(iy+10)
	jr nz,Home_4_Draw_Sphr				;If in spherical vector mode, draw that
	bit 6,(iy+10)
	jr nz,Home_4_Draw_Cyl				;If in cylindrical vector mode, draw that
Home_4_Draw_Rec:						;Otherwise, show that is in rectangular vector mode
	ld hl,Text_Rec						;Set text to be drawn
	jr Home_4_Draw
Home_4_Draw_Cyl:
	ld hl,Text_Cyl						;Set text to be drawn
	jr Home_4_Draw
Home_4_Draw_Sphr:
	ld hl,Text_Sphr						;Set text to be drawn
Home_4_Draw:
	call _vputs							;Now draw
Home_4_Key_Loop:
	call _getkey 
	cp kRight							;Is right key?
	jr z,Home_4_R
	cp kLeft							;Is left key?
	jr z,Home_4_L
	cp kLog								;Is log key?
	jp z,Select_Graph
	cp kGrMenu							;Is graph key?
	jp z,Select_Memory
	cp kUp								;Is up key?
	jp z,Home_3_Handler
	cp kDown							;Is down key?
	jp z,Home_5_Handler
	cp kExit							;Is exit key?
	ret z
	jr Home_4_Key_Loop
Home_4_R:
	bit 7,(iy+10)
	jr nz,Home_4_Select_Rec
	bit 6,(iy+10)
	jr nz,Home_4_Select_Sphr
	jr Home_4_Select_Cyl
Home_4_L:
	bit 7,(iy+10)
	jr nz,Home_4_Select_Cyl
	bit 6,(iy+10)
	jr nz,Home_4_Select_Rec
Home_4_Select_Sphr:
	set 6,(iy+10)
	set 7,(iy+10)
	ld a,(iy+10)
	ld (iy+11),a
	jp Home_4_Refresh
Home_4_Select_Cyl:
	set 6,(iy+10)
	res 7,(iy+10)
	ld a,(iy+10)
	ld (iy+11),a
	jp Home_4_Refresh
Home_4_Select_Rec:
	res 6,(iy+10)
	res 7,(iy+10)
	ld a,(iy+10)
	ld (iy+11),a
	jp Home_4_Refresh

Home_5_Handler:							;Routine for selecting fifth menu item on homescreen submenu
	call Redraw_Home					;Deselect previously selected items
	ld hl,Submenu_Pos_5					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Home_Text_5
	call _vputs
	res textInverse,(iy+textflags)
Home_5_Refresh:
	ld hl,Home_5_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 5,(iy+10)
	jr z,Home_5_Draw_Rec				;If in rectangular mode, draw that
Home_5_Draw_Pol:						;Otherwise, show that is in polar mode
	ld hl,Text_Pol						;Set text to be drawn
	jr Home_5_Draw
Home_5_Draw_Rec:
	ld hl,Text_Rec						;Set text to be drawn
Home_5_Draw:
	call _vputs							;Now draw
Home_5_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,Home_5_R
	cp kLeft							;Is left key?
	jr z,Home_5_R
	cp kLog								;Is log key?
	jp z,Select_Graph
	cp kGrMenu							;Is graph key?
	jp z,Select_Memory
	cp kUp								;Is up key?
	jp z,Home_4_Handler
	cp kDown							;Is down key?
	jr z,Home_6_Handler
	cp kExit							;Is exit key?
	ret z
	jr Home_5_Key_Loop
Home_5_R:
	bit 5,(iy+10)
	jr nz,Home_5_Select_Rec
Home_5_Select_Pol:
	set 5,(iy+10)
	set 5,(iy+11)
	jr Home_5_Refresh
Home_5_Select_Rec:
	res 5,(iy+10)
	res 5,(iy+11)
	jr Home_5_Refresh

Home_6_Handler:							;Routine for selecting sixth menu item on homescreen submenu
	call Redraw_Home					;Deselect previously selected items
	ld hl,Submenu_Pos_6					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Home_Text_6
	call _vputs
	res textInverse,(iy+textflags)
	ld hl,Text_Set						;Draw ">>" message
	call _vputs
Home_6_Key_Loop:
	call _getkey
	cp kLog								;Is log key?
	jp z,Select_Graph
	cp kGrMenu							;Is graph key?
	jp z,Select_Memory
	cp kUp								;Is up key?
	jp z,Home_5_Handler
	cp kRight							;Is right key?
	jr z,Home_6_Get_Num
	cp kDown							;Is down key?
	jr z,Home_7_Handler
	cp kExit							;Is exit key?
	ret z
	jr Home_6_Key_Loop
Home_6_Get_Num:
	ld hl,$c61f
	ld de,Msg_Old_Tol
	ld bc,Msg_New_Tol
	call Draw_Num_Window
	call _runindicoff
	call Redraw_Window
	call Redraw_Main_Menu
	ld hl,Main_Menu_Pos_2				;Reselect homescreen menu
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Main_Menu_Text_2
	call _vputs
	res textInverse,(iy+textflags)
	jr Home_6_Handler

Home_7_Handler:							;Routine for selecting seventh menu item on homescreen submenu
	call Redraw_Home					;Deselect previously selected items
	ld hl,Submenu_Pos_7					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Home_Text_7
	call _vputs
	res textInverse,(iy+textflags)
Home_7_Refresh:
	ld hl,Home_7_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit curLock,(iy+curflags)
	jr nz,Home_7_Draw_Off				;If cursor flash is off, draw that
Home_7_Draw_On:							;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr Home_7_Draw
Home_7_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
Home_7_Draw:
	call _vputs							;Now draw
Home_7_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,Home_7_R
	cp kLeft							;Is left key?
	jr z,Home_7_R
	cp kLog								;Is log key?
	jp z,Select_Graph
	cp kGrMenu							;Is graph key?
	jp z,Select_Memory
	cp kUp								;Is up key?
	jp z,Home_6_Handler
	cp kExit							;Is exit key?
	ret z
	jr Home_7_Key_Loop
Home_7_R:
	bit curLock,(iy+curflags)
	jr nz,Home_7_Select_Off
Home_7_Select_On:
	set curLock,(iy+curflags)
	jr Home_7_Refresh
Home_7_Select_Off:
	res curLock,(iy+curflags)
	jr Home_7_Refresh

Select_Graph:							;Select graph screen submenu
	call Redraw_Main_Menu				;Unselect any other previous menus
	ld hl,Main_Menu_Pos_3				;Invert text for menu item-first set cursor position
	ld (_penCol),hl
	set textInverse,(iy+textflags)		;Set for inverse text draw
	ld hl,Main_Menu_Text_3				;and draw over current main menu item
	call _vputs
	res textInverse,(iy+textflags)		;Set for normal text draw

Graph_1_Handler:						;Routine for selecting first menu item on graph submenu
	call Redraw_Graph					;Deselect previously selected items
	ld hl,Submenu_Pos_1					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Graph_Text_1
	call _vputs
	res textInverse,(iy+textflags)
Graph_1_Refresh:
	ld hl,Graph_1_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 4,(iy+plotflags)
	jr nz,Graph_1_Draw_Func				;If in function graphing mode, draw that
	bit 5,(iy+plotflags)
	jr nz,Graph_1_Draw_Pol				;If in polar mode, draw that
	bit 6,(iy+plotflags)
	jr nz,Graph_1_Draw_Param			;If in parametric mode, draw that
Graph_1_Draw_DifEq:						;Otherwise, show that is in differential equation mode
	ld hl,Text_DifEq					;Set text to be drawn
	jr Graph_1_Draw
Graph_1_Draw_Param:
	ld hl,Text_Param					;Set text to be drawn
	jr Graph_1_Draw
Graph_1_Draw_Pol:
	ld hl,Text_Pol						;Set text to be drawn
	jr Graph_1_Draw
Graph_1_Draw_Func:
	ld hl,Text_Func						;Set text to be drawn
Graph_1_Draw:
	call _vputs							;Now draw
Graph_1_Key_Loop:
	call _getkey 
	cp kRight							;Is right key?
	jr z,Graph_1_R
	cp kLeft							;Is left key?
	jr z,Graph_1_L
	cp kLog								;Is log key?
	jp z,Select_Text
	cp kGrMenu							;Is graph key?
	jp z,Select_Home
	cp kDown							;Is down key?
	jr z,Graph_2_Handler
	cp kExit							;Is exit key?
	ret z
	jr Graph_1_Key_Loop
Graph_1_R:
	bit 4,(iy+plotflags)
	jr nz,Graph_1_Select_Pol
	bit 5,(iy+plotflags)
	jr nz,Graph_1_Select_Param
	bit 6,(iy+plotflags)
	jr nz,Graph_1_Select_DifEq
	jr Graph_1_Select_Func
Graph_1_L:
	bit 4,(iy+plotflags)
	jr nz,Graph_1_Select_DifEq
	bit 5,(iy+plotflags)
	jr nz,Graph_1_Select_Func
	bit 6,(iy+plotflags)
	jr nz,Graph_1_Select_Pol
Graph_1_Select_Param:
	res 4,(iy+plotflags)
	res 5,(iy+plotflags)
	set 6,(iy+plotflags)
	res 7,(iy+plotflags)
	jp Graph_1_Refresh
Graph_1_Select_Pol:
	res 4,(iy+plotflags)
	set 5,(iy+plotflags)
	res 6,(iy+plotflags)
	res 7,(iy+plotflags)
	jp Graph_1_Refresh
Graph_1_Select_Func:
	set 4,(iy+plotflags)
	res 5,(iy+plotflags)
	res 6,(iy+plotflags)
	res 7,(iy+plotflags)
	jp Graph_1_Refresh
Graph_1_Select_DifEq:
	res 4,(iy+plotflags)
	res 5,(iy+plotflags)
	res 6,(iy+plotflags)
	set 7,(iy+plotflags)
	jp Graph_1_Refresh

Graph_2_Handler:						;Routine for selecting second menu item on graph submenu
	call Redraw_Graph					;Deselect previously selected items
	ld hl,Submenu_Pos_2					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Graph_Text_2
	call _vputs
	res textInverse,(iy+textflags)
Graph_2_Refresh:
	ld hl,Graph_2_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit grfdot,(iy+grfdbflags)
	jr nz,Graph_2_Draw_Dot				;If in dot mode, draw that
Graph_2_Draw_Line:						;Otherwise, show that is in line mode
	ld hl,Text_Line						;Set text to be drawn
	jr Graph_2_Draw
Graph_2_Draw_Dot:
	ld hl,Text_Dot						;Set text to be drawn
Graph_2_Draw:
	call _vputs							;Now draw
Graph_2_Key_Loop:
	call _getkey 
	cp kRight							;Is right key?
	jr z,Graph_2_R
	cp kLeft							;Is left key?
	jr z,Graph_2_R
	cp kLog								;Is log key?
	jp z,Select_Text
	cp kGrMenu							;Is graph key?
	jp z,Select_Home
	cp kUp								;Is up key?
	jp z,Graph_1_Handler
	cp kDown							;Is down key?
	jr z,Graph_3_Handler
	cp kExit							;Is exit key?
	ret z
	jr Graph_2_Key_Loop
Graph_2_R:
	bit grfdot,(iy+grfdbflags)
	jr nz,Graph_2_Select_Line
Graph_2_Select_Dot:
	set grfdot,(iy+grfdbflags)
	jr Graph_2_Refresh
Graph_2_Select_Line:
	res grfdot,(iy+grfdbflags)
	jr Graph_2_Refresh

Graph_3_Handler:						;Routine for selecting third menu item on graph submenu
	call Redraw_Graph					;Deselect previously selected items
	ld hl,Submenu_Pos_3					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Graph_Text_3
	call _vputs
	res textInverse,(iy+textflags)
Graph_3_Refresh:
	ld hl,Graph_3_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit grfsimul,(iy+grfdbflags)
	jr nz,Graph_3_Draw_Simul			;If in simultaneous mode, draw that
Graph_3_Draw_Seq:						;Otherwise, show that is in sequential mode
	ld hl,Text_Seq						;Set text to be drawn
	jr Graph_3_Draw
Graph_3_Draw_Simul:
	ld hl,Text_Simul					;Set text to be drawn
Graph_3_Draw:
	call _vputs							;Now draw
Graph_3_Key_Loop:
	call _getkey 
	cp kRight							;Is right key?
	jr z,Graph_3_R
	cp kLeft							;Is left key?
	jr z,Graph_3_R
	cp kLog								;Is log key?
	jp z,Select_Text
	cp kGrMenu							;Is graph key?
	jp z,Select_Home
	cp kUp								;Is up key?
	jp z,Graph_2_Handler
	cp kDown							;Is down key?
	jr z,Graph_4_Handler
	cp kExit							;Is exit key?
	ret z
	jr Graph_3_Key_Loop
Graph_3_R:
	bit grfsimul,(iy+grfdbflags)
	jr nz,Graph_3_Select_Seq
Graph_3_Select_Simul:
	set grfsimul,(iy+grfdbflags)
	jr Graph_3_Refresh
Graph_3_Select_Seq:
	res grfsimul,(iy+grfdbflags)
	jr Graph_3_Refresh

Graph_4_Handler:						;Routine for selecting fourth menu item on graph submenu
	call Redraw_Graph					;Deselect previously selected items
	ld hl,Submenu_Pos_4					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Graph_Text_4
	call _vputs
	res textInverse,(iy+textflags)
Graph_4_Refresh:
	ld hl,Graph_4_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit grfgrid,(iy+grfdbflags)
	jr z,Graph_4_Draw_Off				;If grid is off, draw that
Graph_4_Draw_On:						;Otherwise, show that grid is on
	ld hl,Text_On						;Set text to be drawn
	jr Graph_4_Draw
Graph_4_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
Graph_4_Draw:
	call _vputs							;Now draw
Graph_4_Key_Loop:
	call _getkey 
	cp kRight							;Is right key?
	jr z,Graph_4_R
	cp kLeft							;Is left key?
	jr z,Graph_4_R
	cp kLog								;Is log key?
	jp z,Select_Text
	cp kGrMenu							;Is graph key?
	jp z,Select_Home
	cp kUp								;Is up key?
	jp z,Graph_3_Handler
	cp kDown							;Is down key?
	jr z,Graph_5_Handler
	cp kExit							;Is exit key?
	ret z
	jr Graph_4_Key_Loop
Graph_4_R:
	bit grfgrid,(iy+grfdbflags)
	jr z,Graph_4_Select_On
Graph_4_Select_Off:
	res grfgrid,(iy+grfdbflags)
;	set 3,(iy+0)
	set graphdraw,(iy+graphflags)
	jr Graph_4_Refresh
Graph_4_Select_On:
	set grfgrid,(iy+grfdbflags)
;	res 3,(iy+0)
	set graphdraw,(iy+graphflags)
	jr Graph_4_Refresh

Graph_5_Handler:						;Routine for selecting fifth menu item on graph submenu
	call Redraw_Graph					;Deselect previously selected items
	ld hl,Submenu_Pos_5					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Graph_Text_5
	call _vputs
	res textInverse,(iy+textflags)
Graph_5_Refresh:
	ld hl,Graph_5_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit grfnocoord,(iy+grfdbflags)
	jr nz,Graph_5_Draw_Off				;If coordinates are off, draw that
	bit grfpolar,(iy+grfdbflags)
	jr nz,Graph_5_Draw_Pol				;If polar coordinates, draw that
Graph_5_Draw_Rec:						;Otherwise, show that are rectangular coordinates
	ld hl,Text_Rec						;Set text to be drawn
	jr Graph_5_Draw
Graph_5_Draw_Pol:
	ld hl,Text_Pol						;Set text to be drawn
	jr Graph_5_Draw
Graph_5_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
Graph_5_Draw:
	call _vputs							;Now draw
Graph_5_Key_Loop:
	call _getkey 
	cp kRight							;Is right key?
	jr z,Graph_5_R
	cp kLeft							;Is left key?
	jr z,Graph_5_L
	cp kLog								;Is log key?
	jp z,Select_Text
	cp kGrMenu							;Is graph key?
	jp z,Select_Home
	cp kUp								;Is up key?
	jp z,Graph_4_Handler
	cp kDown							;Is down key?
	jp z,Graph_6_Handler
	cp kExit							;Is exit key?
	ret z
	jr Graph_5_Key_Loop
Graph_5_R:
	bit grfnocoord,(iy+grfdbflags)
	jr nz,Graph_5_Select_Rec
	bit grfpolar,(iy+grfdbflags)
	jr nz,Graph_5_Select_Off
	jr Graph_5_Select_Pol
Graph_5_L:
	bit grfnocoord,(iy+grfdbflags)
	jr nz,Graph_5_Select_Pol
	bit grfpolar,(iy+grfdbflags)
	jr nz,Graph_5_Select_Rec
Graph_5_Select_Off:
	set grfnocoord,(iy+grfdbflags)
	jr Graph_5_Refresh
Graph_5_Select_Pol:
	res grfnocoord,(iy+grfdbflags)
	set grfpolar,(iy+grfdbflags)
	jr Graph_5_Refresh
Graph_5_Select_Rec:
	res grfnocoord,(iy+grfdbflags)
	res grfpolar,(iy+grfdbflags)
	jr Graph_5_Refresh

Graph_6_Handler:						;Routine for selecting sixth menu item on graph submenu
	call Redraw_Graph					;Deselect previously selected items
	ld hl,Submenu_Pos_6					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Graph_Text_6
	call _vputs
	res textInverse,(iy+textflags)
Graph_6_Refresh:
	ld hl,Graph_6_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit grfnoaxis,(iy+grfdbflags)
	jr nz,Graph_6_Draw_Off				;If axes are off, draw that
Graph_6_Draw_On:						;Otherwise, show that axes are on
	ld hl,Text_On						;Set text to be drawn
	jr Graph_6_Draw
Graph_6_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
Graph_6_Draw:
	call _vputs							;Now draw
Graph_6_Key_Loop:
	call _getkey 
	cp kRight							;Is right key?
	jr z,Graph_6_R
	cp kLeft							;Is left key?
	jr z,Graph_6_R
	cp kLog								;Is log key?
	jp z,Select_Text
	cp kGrMenu							;Is graph key?
	jp z,Select_Home
	cp kUp								;Is up key?
	jp z,Graph_5_Handler
	cp kDown							;Is down key?
	jr z,Graph_7_Handler
	cp kExit							;Is exit key?
	ret z
	jr Graph_6_Key_Loop
Graph_6_R:
	bit grfnoaxis,(iy+grfdbflags)
	jr nz,Graph_6_Select_On
Graph_6_Select_Off:
	set grfnoaxis,(iy+grfdbflags)
	set graphdraw,(iy+graphflags)
	jr Graph_6_Refresh
Graph_6_Select_On:
	res grfnoaxis,(iy+grfdbflags)
	set graphdraw,(iy+graphflags)
	jr Graph_6_Refresh

Graph_7_Handler:						;Routine for selecting seventh menu item on graph submenu
	call Redraw_Graph					;Deselect previously selected items
	ld hl,Submenu_Pos_7					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Graph_Text_7
	call _vputs
	res textInverse,(iy+textflags)
Graph_7_Refresh:
	ld hl,Graph_7_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit grflabel,(iy+grfdbflags)
	jr z,Graph_7_Draw_Off				;If labels are off, draw that
Graph_7_Draw_On:						;Otherwise, show that labels are on
	ld hl,Text_On						;Set text to be drawn
	jr Graph_7_Draw
Graph_7_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
Graph_7_Draw:
	call _vputs							;Now draw
Graph_7_Key_Loop:
	call _getkey 
	cp kRight							;Is right key?
	jr z,Graph_7_R
	cp kLeft							;Is left key?
	jr z,Graph_7_R
	cp kLog								;Is log key?
	jp z,Select_Text
	cp kGrMenu							;Is graph key?
	jp z,Select_Home
	cp kUp								;Is up key?
	jp z,Graph_6_Handler
	cp kDown							;Is down key?
	jr z,Graph_8_Handler
	cp kExit							;Is exit key?
	ret z
	jr Graph_7_Key_Loop
Graph_7_R:
	bit grflabel,(iy+grfdbflags)
	jr z,Graph_7_Select_On
Graph_7_Select_Off:
	res grflabel,(iy+grfdbflags)
	jr Graph_7_Refresh
Graph_7_Select_On:
	set grflabel,(iy+grfdbflags)
	jr Graph_7_Refresh

Graph_8_Handler:						;Routine for selecting eighth menu item on graph submenu
	call Redraw_Graph					;Deselect previously selected items
	ld hl,Submenu_Pos_8					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Graph_Text_8
	call _vputs
	res textInverse,(iy+textflags)
Graph_8_Refresh:
	ld hl,Graph_8_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit plotloc,(iy+plotflags)
	jr nz,Graph_8_Draw_Off				;If graph save is off, draw that
Graph_8_Draw_On:						;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr Graph_8_Draw
Graph_8_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
Graph_8_Draw:
	call _vputs							;Now draw
Graph_8_Key_Loop:
	call _getkey 
	cp kRight							;Is right key?
	jr z,Graph_8_R
	cp kLeft							;Is left key?
	jr z,Graph_8_R
	cp kLog								;Is log key?
	jp z,Select_Text
	cp kGrMenu							;Is graph key?
	jp z,Select_Home
	cp kUp								;Is up key?
	jp z,Graph_7_Handler
	cp kExit							;Is exit key?
	ret z
	jr Graph_8_Key_Loop
Graph_8_R:
	bit plotloc,(iy+plotflags)
	jr z,Graph_8_Select_On
Graph_8_Select_Off:
	res plotloc,(iy+plotflags)
	jr Graph_8_Refresh
Graph_8_Select_On:
	set plotloc,(iy+plotflags)
	jr Graph_8_Refresh

Select_Text:							;Select text options submenu
	call Redraw_Main_Menu				;Unselect any other previous menus
	ld hl,Main_Menu_Pos_4				;Invert text for menu item-first set cursor position
	ld (_penCol),hl
	set textInverse,(iy+textflags)		;Set for inverse text draw
	ld hl,Main_Menu_Text_4				;and draw over current main menu item
	call _vputs
	res textInverse,(iy+textflags)		;Set for normal text draw

Text_1_Handler:							;Routine for selecting first menu item on text submenu
	call Redraw_Text					;Deselect previously selected items
	ld hl,Submenu_Pos_1					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Text_Text_1
	call _vputs
	ld hl,Submenu_Pos_2
	ld (_penCol),hl
	ld hl,Text_Text_2
	call _vputs
	res textInverse,(iy+textflags)
Text_1_Refresh:
	ld hl,Text_1_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 1,(iy+textflags)
	jr z,Text_1_Draw_Off				;If erase is off, draw that
Text_1_Draw_On:							;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr Text_1_Draw
Text_1_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
Text_1_Draw:
	call _vputs							;Now draw
Text_1_Key_Loop:
	call _getkey 
	cp kRight							;Is right key?
	jr z,Text_1_R
	cp kLeft							;Is left key?
	jr z,Text_1_R
	cp kLog								;Is log key?
	jp z,Select_User
	cp kGrMenu							;Is graph key?
	jp z,Select_Graph
	cp kDown							;Is down key?
	jr z,Text_2_Handler
	cp kExit							;Is exit key?
	ret z
	jr Text_1_Key_Loop
Text_1_R:
	bit 1,(iy+textflags)
	jr z,Text_1_Select_On
Text_1_Select_Off:
	res 1,(iy+textflags)
	jr Text_1_Refresh
Text_1_Select_On:
	set 1,(iy+textflags)
	jr Text_1_Refresh

Text_2_Handler:							;Routine for selecting second menu item on text submenu
	call Redraw_Text					;Deselect previously selected items
	ld hl,Submenu_Pos_3					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Text_Text_3
	call _vputs
	res textInverse,(iy+textflags)
Text_2_Refresh:
	ld hl,Text_2_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 1,(iy+appflags)
	jr z,Text_2_Draw_Off				;If save is off, draw that
Text_2_Draw_On:							;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr Text_2_Draw
Text_2_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
Text_2_Draw:
	call _vputs							;Now draw
Text_2_Key_Loop:
	call _getkey 
	cp kRight							;Is right key?
	jr z,Text_2_R
	cp kLeft							;Is left key?
	jr z,Text_2_R
	cp kLog								;Is log key?
	jp z,Select_User
	cp kGrMenu							;Is graph key?
	jp z,Select_Graph
	cp kUp								;Is up key?
	jp z,Text_1_Handler
	cp kDown							;Is down key?
	jr z,Text_3_Handler
	cp kExit							;Is exit key?
	ret z
	jr Text_2_Key_Loop
Text_2_R:
	bit 1,(iy+appflags)
	jr z,Text_2_Select_On
Text_2_Select_Off:
	res 1,(iy+appflags)
	jr Text_2_Refresh
Text_2_Select_On:
	set 1,(iy+appflags)
	jr Text_2_Refresh

Text_3_Handler:							;Routine for selecting third menu item on text submenu
	call Redraw_Text					;Deselect previously selected items
	ld hl,Submenu_Pos_4					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Text_Text_4
	call _vputs
	res textInverse,(iy+textflags)
Text_3_Refresh:
	ld hl,Text_3_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 2,(iy+appflags)
	jr z,Text_3_Draw_Off				;If autoscroll is off, draw that
Text_3_Draw_On:							;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr Text_3_Draw
Text_3_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
Text_3_Draw:
	call _vputs							;Now draw
Text_3_Key_Loop:
	call _getkey 
	cp kRight							;Is right key?
	jr z,Text_3_R
	cp kLeft							;Is left key?
	jr z,Text_3_R
	cp kLog								;Is log key?
	jp z,Select_User
	cp kGrMenu							;Is graph key?
	jp z,Select_Graph
	cp kUp								;Is up key?
	jp z,Text_2_Handler
	cp kDown							;Is down key?
	jr z,Text_4_Handler
	cp kExit							;Is exit key?
	ret z
	jr Text_3_Key_Loop
Text_3_R:
	bit 2,(iy+appflags)
	jr z,Text_3_Select_On
Text_3_Select_Off:
	res 2,(iy+appflags)
	jr Text_3_Refresh
Text_3_Select_On:
	set 2,(iy+appflags)
	jr Text_3_Refresh

Text_4_Handler:							;Routine for selecting first menu item on text submenu
	call Redraw_Text					;Deselect previously selected items
	ld hl,Submenu_Pos_5					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Text_Text_5
	call _vputs
	ld hl,Submenu_Pos_6
	ld (_penCol),hl
	ld hl,Text_Text_6
	call _vputs
	res textInverse,(iy+textflags)
Text_4_Refresh:
	ld hl,Text_4_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit textwrite,(iy+$18)
	jr z,Text_4_Draw_Off				;If graph text is off, draw that
Text_4_Draw_On:							;Otherwise, show that is on 
	res textwrite,(iy+$18)				;The "on" wouldn't be displayed if was on, so turn it off
	ld hl,Text_On						;set text to be drawn
	call _vputs							;draw it
	set textwrite,(iy+$18)				;then turn it back on again
	jr Text_4_Key_Loop
Text_4_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
	call _vputs							;Now draw
Text_4_Key_Loop:
	call _getkey 
	cp kRight							;Is right key?
	jr z,Text_4_R
	cp kLeft							;Is left key?
	jr z,Text_4_R
	cp kLog								;Is log key?
	jp z,Select_User
	cp kGrMenu							;Is graph key?
	jp z,Select_Graph
	cp kUp								;Is up key?
	jp z,Text_3_Handler
	cp kExit							;Is exit key?
	ret z
	jr Text_4_Key_Loop
Text_4_R:
	bit textwrite,(iy+$18)
	jr z,Text_4_Select_On
Text_4_Select_Off:
	res textwrite,(iy+$18)
	jr Text_4_Refresh
Text_4_Select_On:
	set textwrite,(iy+$18)
	jr Text_4_Refresh

Select_User:							;Select user routines submenu
	call Redraw_Main_Menu				;Unselect any other previous menus
	ld hl,Main_Menu_Pos_5				;Invert text for menu item-first set cursor position
	ld (_penCol),hl
	set textInverse,(iy+textflags)		;Set for inverse text draw
	ld hl,Main_Menu_Text_5				;and draw over current main menu item
	call _vputs
	res textInverse,(iy+textflags)		;Set for normal text draw

User_1_Handler:							;Routine for selecting first menu item on user submenu
	call Redraw_User					;Deselect previously selected items
	ld hl,Submenu_Pos_1					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,User_Text_1
	call _vputs
	res textInverse,(iy+textflags)
User_1_Refresh:
	ld hl,User_1_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 0,(iy+35)
	jr z,User_1_Draw_Off				;If user large font is off, draw that
User_1_Draw_On:							;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr User_1_Draw
User_1_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
User_1_Draw:
	call _vputs							;Now draw
User_1_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,User_1_R
	cp kLeft							;Is left key?
	jr z,User_1_R
	cp kLog								;Is log key?
	jp z,Select_Misc
	cp kGrMenu							;Is graph key?
	jp z,Select_Text
	cp kDown							;Is down key?
	jr z,User_2_Handler
	cp kExit							;Is exit key?
	ret z
	jr User_1_Key_Loop
User_1_R:
	bit 0,(iy+35)
	jr nz,User_1_Select_Off
User_1_Select_On:
	set 0,(iy+35)
	jr User_1_Refresh
User_1_Select_Off:
	res 0,(iy+35)
	jr User_1_Refresh

User_2_Handler:							;Routine for selecting second menu item on user submenu
	call Redraw_User					;Deselect previously selected items
	ld hl,Submenu_Pos_2					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,User_Text_2
	call _vputs
	res textInverse,(iy+textflags)
User_2_Refresh:
	ld hl,User_2_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 1,(iy+35)
	jr z,User_2_Draw_Off				;If small user font is off, draw that
User_2_Draw_On:							;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr User_2_Draw
User_2_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
User_2_Draw:
	call _vputs							;Now draw
User_2_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,User_2_R
	cp kLeft							;Is left key?
	jr z,User_2_R
	cp kLog								;Is log key?
	jp z,Select_Misc
	cp kGrMenu							;Is graph key?
	jp z,Select_Text
	cp kUp								;Is up key?
	jp z,User_1_Handler
	cp kDown							;Is down key?
	jr z,User_3_Handler
	cp kExit							;Is exit key?
	ret z
	jr User_2_Key_Loop
User_2_R:
	bit 1,(iy+35)
	jr nz,User_2_Select_Off
User_2_Select_On:
	set 1,(iy+35)
	jr User_2_Refresh
User_2_Select_Off:
	res 1,(iy+35)
	jr User_2_Refresh

User_3_Handler:							;Routine for selecting third menu item on user submenu
	call Redraw_User					;Deselect previously selected items
	ld hl,Submenu_Pos_3					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,User_Text_3
	call _vputs
	res textInverse,(iy+textflags)
User_3_Refresh:
	ld hl,User_3_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 2,(iy+35)
	jr z,User_3_Draw_Off				;If interrupt routine is off, draw that
User_3_Draw_On:							;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr User_3_Draw
User_3_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
User_3_Draw:
	call _vputs							;Now draw
User_3_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,User_3_R
	cp kLeft							;Is left key?
	jr z,User_3_R
	cp kLog								;Is log key?
	jp z,Select_Misc
	cp kGrMenu							;Is graph key?
	jp z,Select_Text
	cp kUp								;Is up key?
	jp z,User_2_Handler
	cp kDown							;Is down key?
	jr z,User_4_Handler
	cp kExit							;Is exit key?
	ret z
	jr User_3_Key_Loop
User_3_R:
	bit 2,(iy+35)
	jr nz,User_3_Select_Off
User_3_Select_On:
	set 2,(iy+35)
	jr User_3_Refresh
User_3_Select_Off:
	res 2,(iy+35)
	jr User_3_Refresh

User_4_Handler:							;Routine for selecting fourth menu item on user submenu
	call Redraw_User					;Deselect previously selected items
	ld hl,Submenu_Pos_4					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,User_Text_4
	call _vputs
	res textInverse,(iy+textflags)
User_4_Refresh:
	ld hl,User_4_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 3,(iy+35)
	jr z,User_4_Draw_Off				;If on routine is off, draw that
User_4_Draw_On:							;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr User_4_Draw
User_4_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
User_4_Draw:
	call _vputs							;Now draw
User_4_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,User_4_R
	cp kLeft							;Is left key?
	jr z,User_4_R
	cp kLog								;Is log key?
	jp z,Select_Misc
	cp kGrMenu							;Is graph key?
	jp z,Select_Text
	cp kUp								;Is up key?
	jp z,User_3_Handler
	cp kDown							;Is down key?
	jr z,User_5_Handler
	cp kExit							;Is exit key?
	ret z
	jr User_4_Key_Loop
User_4_R:
	bit 3,(iy+35)
	jr nz,User_4_Select_Off
User_4_Select_On:
	set 3,(iy+35)
	jr User_4_Refresh
User_4_Select_Off:
	res 3,(iy+35)
	jr User_4_Refresh

User_5_Handler:							;Routine for selecting fifth menu item on user submenu
	call Redraw_User					;Deselect previously selected items
	ld hl,Submenu_Pos_5					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,User_Text_5
	call _vputs
	res textInverse,(iy+textflags)
User_5_Refresh:
	ld hl,User_5_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 7,(iy+35)
	jr z,User_5_Draw_Off				;If off routine is off, draw that
User_5_Draw_On:							;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr User_5_Draw
User_5_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
User_5_Draw:
	call _vputs							;Now draw
User_5_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,User_5_R
	cp kLeft							;Is left key?
	jr z,User_5_R
	cp kLog								;Is log key?
	jp z,Select_Misc
	cp kGrMenu							;Is graph key?
	jp z,Select_Text
	cp kUp								;Is up key?
	jp z,User_4_Handler
	cp kDown							;Is down key?
	jr z,User_6_Handler
	cp kExit							;Is exit key?
	ret z
	jr User_5_Key_Loop
User_5_R:
	bit 7,(iy+35)
	jr nz,User_5_Select_Off
User_5_Select_On:
	set 7,(iy+35)
	jr User_5_Refresh
User_5_Select_Off:
	res 7,(iy+35)
	jr User_5_Refresh

User_6_Handler:							;Routine for selecting sixth menu item on user submenu
	call Redraw_User					;Deselect previously selected items
	ld hl,Submenu_Pos_6					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,User_Text_6
	call _vputs
	res textInverse,(iy+textflags)
User_6_Refresh:
	ld hl,User_6_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 4,(iy+35)
	jr z,User_6_Draw_Off				;If link routine is off, draw that
User_6_Draw_On:							;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr User_6_Draw
User_6_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
User_6_Draw:
	call _vputs							;Now draw
User_6_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,User_6_R
	cp kLeft							;Is left key?
	jr z,User_6_R
	cp kLog								;Is log key?
	jp z,Select_Misc
	cp kGrMenu							;Is graph key?
	jp z,Select_Text
	cp kUp								;Is up key?
	jp z,User_5_Handler
	cp kDown							;Is down key?
	jr z,User_7_Handler
	cp kExit							;Is exit key?
	ret z
	jr User_6_Key_Loop
User_6_R:
	bit 4,(iy+35)
	jr nz,User_6_Select_Off
User_6_Select_On:
	set 4,(iy+35)
	jr User_6_Refresh
User_6_Select_Off:
	res 4,(iy+35)
	jr User_6_Refresh

User_7_Handler:							;Routine for selecting seventh menu item on user submenu
	call Redraw_User					;Deselect previously selected items
	ld hl,Submenu_Pos_7					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,User_Text_7
	call _vputs
	res textInverse,(iy+textflags)
User_7_Refresh:
	ld hl,User_7_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 0,(iy+36)
	jr z,User_7_Draw_Off				;If (sqrt)Parse is off, draw that
User_7_Draw_On:							;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr User_7_Draw
User_7_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
User_7_Draw:
	call _vputs							;Now draw
User_7_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,User_7_R
	cp kLeft							;Is left key?
	jr z,User_7_R
	cp kLog								;Is log key?
	jp z,Select_Misc
	cp kGrMenu							;Is graph key?
	jp z,Select_Text
	cp kUp								;Is up key?
	jp z,User_6_Handler
	cp kDown							;Is down key?
	jr z,User_8_Handler
	cp kExit							;Is exit key?
	ret z
	jr User_7_Key_Loop
User_7_R:
	bit 0,(iy+36)
	jr nz,User_7_Select_Off
User_7_Select_On:
;	ld hl,Parse_Name					;Find if it exists
;	call _mov10toop1
;	call _FINDSYM
;	jr c,User_7_Key_Loop				;If it doesn't, don't turn on
	set 0,(iy+36)
	jr User_7_Refresh
User_7_Select_Off:
	res 0,(iy+36)
	jr User_7_Refresh

User_8_Handler:							;Routine for selecting eighth menu item on user submenu
	call Redraw_User					;Deselect previously selected items
	ld hl,Submenu_Pos_8					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,User_Text_8
	call _vputs
	res textInverse,(iy+textflags)
User_8_Refresh:
	ld hl,User_8_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 1,(iy+36)
	jr z,User_8_Draw_Off				;If (sqrt)Form is off, draw that
User_8_Draw_On:							;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr User_8_Draw
User_8_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
User_8_Draw:
	call _vputs							;Now draw
User_8_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,User_8_R
	cp kLeft							;Is left key?
	jr z,User_8_R
	cp kLog								;Is log key?
	jp z,Select_Misc
	cp kGrMenu							;Is graph key?
	jp z,Select_Text
	cp kUp								;Is up key?
	jp z,User_7_Handler
	cp kDown							;Is down key?
	jr z,User_9_Handler
	cp kExit							;Is exit key?
	ret z
	jr User_8_Key_Loop
User_8_R:
	bit 1,(iy+36)
	jr nz,User_8_Select_Off
User_8_Select_On:
;	ld hl,Form_Name						;Find if it exists
;	call _mov10toop1
;	call _FINDSYM
;	jr c,User_8_Key_Loop				;If it doesn't, don't turn on
	set 1,(iy+36)
	jr User_8_Refresh
User_8_Select_Off:
	res 1,(iy+36)
	jr User_8_Refresh

User_9_Handler:							;Routine for selecting ninth menu item on user submenu
	call Redraw_User_2					;Deselect previously selected items
	ld hl,Submenu_Pos_1					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,User_Text_9
	call _vputs
	res textInverse,(iy+textflags)
User_9_Refresh:
	ld hl,User_9_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 2,(iy+36)
	jr z,User_9_Draw_Off				;If (sqrt)Exec is off, draw that
User_9_Draw_On:							;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr User_9_Draw
User_9_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
User_9_Draw:
	call _vputs							;Now draw
User_9_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,User_9_R
	cp kLeft							;Is left key?
	jr z,User_9_R
	cp kLog								;Is log key?
	jp z,Select_Misc
	cp kGrMenu							;Is graph key?
	jp z,Select_Text
	cp kUp								;Is up key?
	jp z,User_8_Handler
	cp kDown							;Is down key?
	jr z,User_10_Handler
	cp kExit							;Is exit key?
	ret z
	jr User_9_Key_Loop
User_9_R:
	bit 2,(iy+36)
	jr nz,User_9_Select_Off
User_9_Select_On:
;	ld hl,Exec_Name						;Find if it exists
;	call _mov10toop1
;	call _FINDSYM
;	jr c,User_9_Key_Loop				;If it doesn't, don't turn on
	set 2,(iy+36)
	jr User_9_Refresh
User_9_Select_Off:
	res 2,(iy+36)
	jr User_9_Refresh

User_10_Handler:						;Routine for selecting tenth menu item on user submenu
	call Redraw_User_2					;Deselect previously selected items
	ld hl,Submenu_Pos_2					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,User_Text_10
	call _vputs
	res textInverse,(iy+textflags)
User_10_Refresh:
	ld hl,User_10_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 3,(iy+36)
	jr z,User_10_Draw_Off				;If (sqrt)Expr is off, draw that
User_10_Draw_On:						;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr User_10_Draw
User_10_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
User_10_Draw:
	call _vputs							;Now draw
User_10_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,User_10_R
	cp kLeft							;Is left key?
	jr z,User_10_R
	cp kLog								;Is log key?
	jp z,Select_Misc
	cp kGrMenu							;Is graph key?
	jp z,Select_Text
	cp kUp								;Is up key?
	jp z,User_9_Handler
	cp kDown							;Is down key?
	jr z,User_11_Handler
	cp kExit							;Is exit key?
	ret z
	jr User_10_Key_Loop
User_10_R:
	bit 3,(iy+36)
	jr nz,User_10_Select_Off
User_10_Select_On:
;	ld hl,Expr_Name						;Find if it exists
;	call _mov10toop1
;	call _FINDSYM
;	jr c,User_10_Key_Loop				;If it doesn't, don't turn on
	set 3,(iy+36)
	jr User_10_Refresh
User_10_Select_Off:
	res 3,(iy+36)
	jr User_10_Refresh

User_11_Handler:						;Routine for selecting eleventh menu item on user submenu
	call Redraw_User_2					;Deselect previously selected items
	ld hl,Submenu_Pos_3					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,User_Text_11
	call _vputs
	res textInverse,(iy+textflags)
User_11_Refresh:
	ld hl,User_11_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 4,(iy+36)
	jr z,User_11_Draw_Off				;If (sqrt)Home is off, draw that
User_11_Draw_On:						;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr User_11_Draw
User_11_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
User_11_Draw:
	call _vputs							;Now draw
User_11_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,User_11_R
	cp kLeft							;Is left key?
	jr z,User_11_R
	cp kLog								;Is log key?
	jp z,Select_Misc
	cp kGrMenu							;Is graph key?
	jp z,Select_Text
	cp kUp								;Is up key?
	jp z,User_10_Handler
	cp kDown							;Is down key?
	jr z,User_12_Handler
	cp kExit							;Is exit key?
	ret z
	jr User_11_Key_Loop
User_11_R:
	bit 4,(iy+36)
	jr nz,User_11_Select_Off
User_11_Select_On:
;	ld hl,Home_Name						;Find if it exists
;	call _mov10toop1
;	call _FINDSYM
;	jr c,User_11_Key_Loop				;If it doesn't, don't turn on
	set 4,(iy+36)
	jr User_11_Refresh
User_11_Select_Off:
	res 4,(iy+36)
	jr User_11_Refresh

User_12_Handler:						;Routine for selecting twelfth menu item on user submenu
	call Redraw_User_2					;Deselect previously selected items
	ld hl,Submenu_Pos_4					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,User_Text_12
	call _vputs
	res textInverse,(iy+textflags)
User_12_Refresh:
	ld hl,User_12_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 5,(iy+36)
	jr z,User_12_Draw_Off				;If (sqrt)CmdTok is off, draw that
User_12_Draw_On:						;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr User_12_Draw
User_12_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
User_12_Draw:
	call _vputs							;Now draw
User_12_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,User_12_R
	cp kLeft							;Is left key?
	jr z,User_12_R
	cp kLog								;Is log key?
	jp z,Select_Misc
	cp kGrMenu							;Is graph key?
	jp z,Select_Text
	cp kUp								;Is up key?
	jp z,User_11_Handler
	cp kDown							;Is down key?
	jr z,User_13_Handler
	cp kExit							;Is exit key?
	ret z
	jr User_12_Key_Loop
User_12_R:
	bit 5,(iy+36)
	jr nz,User_12_Select_Off
User_12_Select_On:
;	ld hl,CmdTok_Name					;Find if it exists
;	call _mov10toop1
;	call _FINDSYM
;	jr c,User_12_Key_Loop				;If it doesn't, don't turn on
	set 5,(iy+36)
	jr User_12_Refresh
User_12_Select_Off:
	res 5,(iy+36)
	jr User_12_Refresh

User_13_Handler:						;Routine for selecting thirteenth menu item on user submenu
	call Redraw_User_2					;Deselect previously selected items
	ld hl,Submenu_Pos_5					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,User_Text_13
	call _vputs
	res textInverse,(iy+textflags)
User_13_Refresh:
	ld hl,User_13_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 6,(iy+36)
	jr z,User_13_Draw_Off				;If (sqrt)Key is off, draw that
User_13_Draw_On:						;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr User_13_Draw
User_13_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
User_13_Draw:
	call _vputs							;Now draw
User_13_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,User_13_R
	cp kLeft							;Is left key?
	jr z,User_13_R
	cp kLog								;Is log key?
	jp z,Select_Misc
	cp kGrMenu							;Is graph key?
	jp z,Select_Text
	cp kUp								;Is up key?
	jp z,User_12_Handler
	cp kDown							;Is down key?
	jr z,User_14_Handler
	cp kExit							;Is exit key?
	ret z
	jr User_13_Key_Loop
User_13_R:
	bit 6,(iy+36)
	jr nz,User_13_Select_Off
User_13_Select_On:
;	ld hl,Key_Name						;Find if it exists
;	call _mov10toop1
;	call _FINDSYM
;	jr c,User_13_Key_Loop				;If it doesn't, don't turn on
	set 6,(iy+36)
	jr User_13_Refresh
User_13_Select_Off:
	res 6,(iy+36)
	jr User_13_Refresh

User_14_Handler:						;Routine for selecting fourteenth menu item on user submenu
	call Redraw_User_2					;Deselect previously selected items
	ld hl,Submenu_Pos_6					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,User_Text_14
	call _vputs
	res textInverse,(iy+textflags)
User_14_Refresh:
	ld hl,User_14_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 7,(iy+36)
	jr z,User_14_Draw_Off				;If (sqrt)Grf is off, draw that
User_14_Draw_On:						;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr User_14_Draw
User_14_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
User_14_Draw:
	call _vputs							;Now draw
User_14_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,User_14_R
	cp kLeft							;Is left key?
	jr z,User_14_R
	cp kLog								;Is log key?
	jp z,Select_Misc
	cp kGrMenu							;Is graph key?
	jp z,Select_Text
	cp kUp								;Is up key?
	jp z,User_13_Handler
	cp kExit							;Is exit key?
	ret z
	jr User_14_Key_Loop
User_14_R:
	bit 7,(iy+36)
	jr nz,User_14_Select_Off
User_14_Select_On:
;	ld hl,Grf_Name						;Find if it exists
;	call _mov10toop1
;	call _FINDSYM
;	jr c,User_14_Key_Loop				;If it doesn't, don't turn on
	set 7,(iy+36)
	jr User_14_Refresh
User_14_Select_Off:
	res 7,(iy+36)
	jr User_14_Refresh

Select_Misc:							;Select misc options submenu
	call Redraw_Main_Menu				;Unselect any other previous menus
	ld hl,Main_Menu_Pos_6				;Invert text for menu item-first set cursor position
	ld (_penCol),hl
	set textInverse,(iy+textflags)		;Set for inverse text draw
	ld hl,Main_Menu_Text_6				;and draw over current main menu item
	call _vputs
	res textInverse,(iy+textflags)		;Set for normal text draw

Misc_1_Handler:							;Routine for selecting first menu item on misc submenu
	call Redraw_Misc					;Deselect previously selected items
	ld hl,Submenu_Pos_1					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Misc_Text_1
	call _vputs
	res textInverse,(iy+textflags)
Misc_1_Refresh:
	ld hl,Misc_1_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit indicRun,(iy+indicflags)
	jr z,Misc_1_Draw_Off				;If run indicator is off, draw that
Misc_1_Draw_On:							;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr Misc_1_Draw
Misc_1_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
Misc_1_Draw:
	call _vputs							;Now draw
Misc_1_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,Misc_1_R
	cp kLeft							;Is left key?
	jr z,Misc_1_R
	cp kGrMenu							;Is graph key?
	jp z,Select_User
	cp kDown							;Is down key?
	jr z,Misc_2_Handler
	cp kExit							;Is exit key?
	ret z
	jr Misc_1_Key_Loop
Misc_1_R:
	bit indicRun,(iy+indicflags)
	jr nz,Misc_1_Select_Off
Misc_1_Select_On:
	call _runindicon
	jr Misc_1_Refresh
Misc_1_Select_Off:
	call _runindicoff
	jr Misc_1_Refresh

Misc_2_Handler:							;Routine for selecting second menu item on misc submenu
	call Redraw_Misc					;Deselect previously selected items
	ld hl,Submenu_Pos_2					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Misc_Text_2
	call _vputs
	res textInverse,(iy+textflags)
Misc_2_Refresh:
	ld hl,Misc_2_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	bit 2,(iy+8)
	jr z,Misc_2_Draw_Off				;If APD is off, draw that
Misc_2_Draw_On:							;Otherwise, show that is on
	ld hl,Text_On						;Set text to be drawn
	jr Misc_2_Draw
Misc_2_Draw_Off:
	ld hl,Text_Off						;Set text to be drawn
Misc_2_Draw:
	call _vputs							;Now draw
Misc_2_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,Misc_2_R
	cp kLeft							;Is left key?
	jr z,Misc_2_R
	cp kGrMenu							;Is graph key?
	jp z,Select_User
	cp kUp								;Is up key?
	jp z,Misc_1_Handler
	cp kDown							;Is down key?
	jr z,Misc_3_Handler
	cp kExit							;Is exit key?
	ret z
	jr Misc_2_Key_Loop
Misc_2_R:
	bit 2,(iy+8)
	jr nz,Misc_2_Select_Off
Misc_2_Select_On:
	set 2,(iy+8)
	jr Misc_2_Refresh
Misc_2_Select_Off:
	res 2,(iy+8)
	jr Misc_2_Refresh

Misc_3_Handler:							;Routine for selecting third menu item on misc submenu
	call Redraw_Misc					;Deselect previously selected items
	ld hl,Submenu_Pos_3					;Invert item text
	ld (_penCol),hl
	set textInverse,(iy+textflags)
	ld hl,Misc_Text_3
	call _vputs
	res textInverse,(iy+textflags)
Misc_3_Refresh:
	ld hl,Misc_3_Text_End				;Position cursor at end of text
	ld (_penCol),hl
	ld a,($c008)						;Get contrast
	call _unpack_hex
	ld hl,_OP1							;Put into OP1
	ld a,c
	add a,$30
	ld (hl),a
	inc hl
	ld a,b
	add a,$30
	ld (hl),a
	inc hl
	ld (hl),0
	dec hl
	dec hl
	call _vputs							;and display
	ld hl,Text_R_L						;Now display right/left arrows
	call _vputs
Misc_3_Key_Loop:
	call _getkey
	cp kRight							;Is right key?
	jr z,Misc_3_R
	cp kLeft							;Is left key?
	jr z,Misc_3_L
	cp kGrMenu							;Is graph key?
	jp z,Select_User
	cp kUp								;Is up key?
	jp z,Misc_2_Handler
	cp kExit							;Is exit key?
	ret z
	jr Misc_3_Key_Loop
Misc_3_R:
	ld hl,$c008							;Increase contrast
	ld a,(hl)
	cp 31								;Is at max?
	jr z,Misc_3_Key_Loop				;If it is, don't increase any more
	inc a
	ld (hl),a
	out (2),a
	jr Misc_3_Refresh
Misc_3_L:
	ld hl,$c008							;Decrease contrast
	ld a,(hl)
	or a								;Is at min?
	jr z,Misc_3_Key_Loop				;If it is, don't decrease any more
	dec a
	ld (hl),a
	out (2),a
	jr Misc_3_Refresh

;////////////////////////////////////////////ROUTINES///////////////////////////////////////////////

Redraw_Window:
	call _clrLCD						;Clear screen
	ld hl,$fc00							;Draw v line on left of screen
	ld a,%10000000
	call V_Line
	ld hl,$fc00+15						;Draw v line on right of screen
	ld a,%00000001
	call V_Line
	ld hl,$fc00+(10*16)+5				;Draw v line in middle of screen
	ld a,%00000001
	call V_Line
	ld hl,$fc00							;Draw h line at top of screen for top of title bar
	call H_Line
	ld hl,$fc00+(9*16)					;Draw h line for bottom of title bar
	call H_Line
	ld hl,$ffff-15						;Draw h line at bottom of screen
	call H_Line
	ld hl,$0202							;Position cursor
	ld (_penCol),hl
	ld hl,Title_Str						;Draw title text
	jp _vputs

Redraw_Main_Menu:						;Draw main menu
	ld hl,Main_Menu_Pos_1				;Position cursor
	ld (_penCol),hl
	ld hl,Main_Menu_Text_1				;Draw text
	call _vputs
	ld hl,Main_Menu_Pos_2
	ld (_penCol),hl
	ld hl,Main_Menu_Text_2
	call _vputs
	ld hl,Main_Menu_Pos_3
	ld (_penCol),hl
	ld hl,Main_Menu_Text_3
	call _vputs
	ld hl,Main_Menu_Pos_4
	ld (_penCol),hl
	ld hl,Main_Menu_Text_4
	call _vputs
	ld hl,Main_Menu_Pos_5
	ld (_penCol),hl
	ld hl,Main_Menu_Text_5
	call _vputs
	ld hl,Main_Menu_Pos_6
	ld (_penCol),hl
	ld hl,Main_Menu_Text_6
	jp _vputs

Redraw_Home:							;Draw homescreen submenu
	call Clear_Submenu_Text				;Clear submenu text area
	ld hl,Submenu_Pos_1					;Set cursor position for drawing submenu
	ld (_penCol),hl
	ld hl,Home_Text_1					;Set text
	call _vputs							;and draw
	ld hl,Submenu_Pos_2
	ld (_penCol),hl
	ld hl,Home_Text_2
	call _vputs
	ld hl,Submenu_Pos_3
	ld (_penCol),hl
	ld hl,Home_Text_3
	call _vputs
	ld hl,Submenu_Pos_4
	ld (_penCol),hl
	ld hl,Home_Text_4
	call _vputs
	ld hl,Submenu_Pos_5
	ld (_penCol),hl
	ld hl,Home_Text_5
	call _vputs
	ld hl,Submenu_Pos_6
	ld (_penCol),hl
	ld hl,Home_Text_6
	call _vputs
	ld hl,Submenu_Pos_7
	ld (_penCol),hl
	ld hl,Home_Text_7
	jp _vputs

Redraw_Graph:							;Draw graph submenu
	call Clear_Submenu_Text				;Clear submenu text area
	ld hl,Submenu_Pos_1					;Set cursor position for drawing submenu
	ld (_penCol),hl
	ld hl,Graph_Text_1					;Set text
	call _vputs							;and draw
	ld hl,Submenu_Pos_2
	ld (_penCol),hl
	ld hl,Graph_Text_2
	call _vputs
	ld hl,Submenu_Pos_3
	ld (_penCol),hl
	ld hl,Graph_Text_3
	call _vputs
	ld hl,Submenu_Pos_4
	ld (_penCol),hl
	ld hl,Graph_Text_4
	call _vputs
	ld hl,Submenu_Pos_5
	ld (_penCol),hl
	ld hl,Graph_Text_5
	call _vputs
	ld hl,Submenu_Pos_6
	ld (_penCol),hl
	ld hl,Graph_Text_6
	call _vputs
	ld hl,Submenu_Pos_7
	ld (_penCol),hl
	ld hl,Graph_Text_7
	call _vputs
	ld hl,Submenu_Pos_8
	ld (_penCol),hl
	ld hl,Graph_Text_8
	jp _vputs

Redraw_Text:
	call Clear_Submenu_Text
	ld hl,Submenu_Pos_1					;Set cursor position for drawing submenu
	ld (_penCol),hl
	ld hl,Text_Text_1					;Set text
	call _vputs							;and draw
	ld hl,Submenu_Pos_2
	ld (_penCol),hl
	ld hl,Text_Text_2
	call _vputs
	ld hl,Submenu_Pos_3
	ld (_penCol),hl
	ld hl,Text_Text_3
	call _vputs
	ld hl,Submenu_Pos_4
	ld (_penCol),hl
	ld hl,Text_Text_4
	call _vputs
	ld hl,Submenu_Pos_5
	ld (_penCol),hl
	ld hl,Text_Text_5
	call _vputs
	ld hl,Submenu_Pos_6
	ld (_penCol),hl
	ld hl,Text_Text_6
	jp _vputs

Redraw_User:
	call Clear_Submenu_Text
	ld hl,Submenu_Pos_1					;Set cursor position for drawing submenu
	ld (_penCol),hl
	ld hl,User_Text_1					;Set text
	call _vputs							;and draw
	ld hl,Submenu_Pos_2
	ld (_penCol),hl
	ld hl,User_Text_2
	call _vputs
	ld hl,Submenu_Pos_3
	ld (_penCol),hl
	ld hl,User_Text_3
	call _vputs
	ld hl,Submenu_Pos_4
	ld (_penCol),hl
	ld hl,User_Text_4
	call _vputs
	ld hl,Submenu_Pos_5
	ld (_penCol),hl
	ld hl,User_Text_5
	call _vputs
	ld hl,Submenu_Pos_6
	ld (_penCol),hl
	ld hl,User_Text_6
	call _vputs
	ld hl,Submenu_Pos_7
	ld (_penCol),hl
	ld hl,User_Text_7
	call _vputs
	ld hl,Submenu_Pos_8
	ld (_penCol),hl
	ld hl,User_Text_8
	jp _vputs

Redraw_User_2:
	call Clear_Submenu_Text
	ld hl,Submenu_Pos_1					;Set cursor position for drawing submenu
	ld (_penCol),hl
	ld hl,User_Text_9					;Set text
	call _vputs							;and draw
	ld hl,Submenu_Pos_2
	ld (_penCol),hl
	ld hl,User_Text_10
	call _vputs
	ld hl,Submenu_Pos_3
	ld (_penCol),hl
	ld hl,User_Text_11
	call _vputs
	ld hl,Submenu_Pos_4
	ld (_penCol),hl
	ld hl,User_Text_12
	call _vputs
	ld hl,Submenu_Pos_5
	ld (_penCol),hl
	ld hl,User_Text_13
	call _vputs
	ld hl,Submenu_Pos_6
	ld (_penCol),hl
	ld hl,User_Text_14
	jp _vputs

Redraw_Misc:
	call Clear_Submenu_Text
	ld hl,Submenu_Pos_1					;Set cursor position for drawing submenu
	ld (_penCol),hl
	ld hl,Misc_Text_1					;Set text
	call _vputs							;and draw
	ld hl,Submenu_Pos_2
	ld (_penCol),hl
	ld hl,Misc_Text_2
	call _vputs
	ld hl,Submenu_Pos_3
	ld (_penCol),hl
	ld hl,Misc_Text_3
	jp _vputs

Draw_Num_Window:						;Draw window for entering number, display old num at (hl),
										;get new num, store to (hl)
	push hl
	push bc
	push hl								;Push pointers
	push de
	call _clrScrn						;Clear screen and text shadow, to remove old entered number
	call _homeup						;Reset cursor position
	pop hl								;Restore "old text" pointer,
	call _puts							;and draw
	pop hl								;Restore pointer to number
	call _mov10toop1					;Move number to OP1
	call _dispOP1						;Display it
	call _newline						;Move to next line
	pop hl								;Restore "new text" pointer,
	ld de,_ioPrompt						;and set as prompt
	call _mov10b
	ld a,$0d							;Set to get number
	ld ($d623),a
	call $5714							;Get it in OP1
	pop de								;Restore pointer to number in de
	jp _movfroop1						;and move number from OP1 to (de)

Clear_Submenu_Text:						;Clear area for submenu text
	ld hl,$fcb6							;Set starting byte for clear
	ld b,50								;Set number of lines to clear
Clear_Text_Loop:						;Line clear loop
	push bc								;Save loop counter, is destroyed in nested loop
	ld b,8								;Set number of columns to clear on each line for nested loop
Clear_Text_Loop_2:						;Nested column clear loop
	ld (hl),0							;Clear current position
	inc hl								;Point to next position
	djnz Clear_Text_Loop_2				;Loop until line is cleared
	pop bc								;Nested loop is done-restore outer loop counter
	ld (hl),0							;Clear current position
	ld de,8								;Set pointer to beginning of next line
	add hl,de
	djnz Clear_Text_Loop				;and loop until all lines are cleared
	ret

V_Line:
	ld de,16
	ld b,64
V_Line_Loop:
	ld (hl),a
	add hl,de
	djnz V_Line_Loop
	ret

H_Line:
	ld b,16
H_Line_Loop:
	ld (hl),$ff
	inc hl
	djnz H_Line_Loop
	ret

Display_AHL:
	call $3d0a
	xor a
	ld (_OP1+6),a
	ld hl,_OP1
	jp _vputs

;////////////////////////////////////////////RESOURCES//////////////////////////////////////////////

Title_Str: .db "Complete System Manager v1.0",0

Main_Menu_Text_1:
	.db "Memory",0
Main_Menu_Text_2:
	.db "Homescreen",0
Main_Menu_Text_3:
	.db "Graphing",0
Main_Menu_Text_4:
	.db "Text",0
Main_Menu_Text_5:
	.db "User routines",0
Main_Menu_Text_6:
	.db "Misc",0

Memory_Text_1:
	.db "Total memory: 98226",0
Memory_Text_2:
	.db "Used: ",0
Memory_Text_3:
	.db "Free: ",0

Home_Text_1:
	.db "Notation:",0
Home_Text_2:
	.db "Angle units:",0
Home_Text_3:
	.db "Number bases:",0
Home_Text_4:
	.db "Vector types:",0
Home_Text_5:
	.db "Cplx numbers:",0
Home_Text_6:
	.db "Tolerance:",0
Home_Text_7:
	.db "Cursor:",0

Graph_Text_1:
	.db "Equation type:",0
Graph_Text_2:
	.db "Line type:",0
Graph_Text_3:
	.db "Draw order:",0
Graph_Text_4:
	.db "Grid:",0
Graph_Text_5:
	.db "Coordinates:",0
Graph_Text_6:
	.db "Axes:",0
Graph_Text_7:
	.db "Labels:",0
Graph_Text_8:
	.db "Save to buffer:",0

Text_Text_1:
	.db "Clear line below",0
Text_Text_2:
	.db "small text:",0
Text_Text_3:
	.db "Save text:",0
Text_Text_4:
	.db "Autoscroll:",0
Text_Text_5:
	.db "Write small text to",0
Text_Text_6:
	.db "graph,not screen:",0

User_Text_1:
	.db "User large font:",0
User_Text_2:
	.db "User small font:",0
User_Text_3:
	.db "Interrupt routine:",0
User_Text_4:
	.db "On routine:",0
User_Text_5:
	.db "Off routine:",0
User_Text_6:
	.db "Link routine:",0
;User_Text_7:
;	.db $10,"Parse:",0
;User_Text_8:
;	.db $10,"Form:",0
;User_Text_9:
;	.db $10,"Exec:",0
;User_Text_10:
;	.db $10,"Expr:",0
;User_Text_11:
;	.db $10,"Home:",0
;User_Text_12:
;	.db $10,"CmdTok:",0
;User_Text_13:
;	.db $10,"Key:",0
;User_Text_14:
;	.db $10,"Grf:",0

Misc_Text_1:
	.db "Run indicator:",0
Misc_Text_2:
	.db "Auto Power Down:",0
Misc_Text_3:
	.db "Contrast:",0

Msg_Old_Tol:
	.db "  Old tol=",0
Msg_New_Tol:
	.db "  New tol=",0

Text_Norm:
	.db "Norm",0
Text_Sci:
	.db "Sci         ",0
Text_Eng:
	.db "Eng       ",0
Text_Rad:
	.db "Rad",0
Text_Deg:
	.db "Deg",0
Text_Bin:
	.db "Bin ",0
Text_Oct:
	.db "Oct",0
Text_Hex:
	.db "Hex",0
Text_Dec:
	.db "Dec",0
Text_Rec:
	.db "Rec    ",0
Text_Pol:
	.db "Pol         ",0
Text_Cyl:
	.db "Cyl    ",0
Text_Sphr:
	.db "Sphr",0
Text_Set:
	.db " >>",0
Text_On:
	.db "On ",0
Text_Off:
	.db "Off ",0
Text_Func:
	.db "Func     ",0
Text_Param:
	.db "Param",0
Text_DifEq:
	.db "DifEq    ",0
Text_Line:
	.db "Line",0
Text_Dot:
	.db "Dot  ",0
Text_Simul:
	.db "Simul",0
Text_Seq:
	.db "Seq      ",0
Text_R_L:
	.db $cf,$05,0

;Parse_Name:
;	.db $12,6
User_Text_7:
	.db $10,"Parse:",0
;Form_Name:
;	.db $12,5
User_Text_8:
	.db $10,"Form:",0
;Exec_Name:
;	.db $12,5
User_Text_9:
	.db $10,"Exec:",0
;Expr_Name:
;	.db $12,5
User_Text_10:
	.db $10,"Expr:",0
;Home_Name:
;	.db $12,5
User_Text_11:
	.db $10,"Home:",0
;CmdTok_Name:
;	.db $12,7
User_Text_12:
	.db $10,"CmdTok:",0
;Key_Name:
;	.db $12,4
User_Text_13:
	.db $10,"Key:",0
;Grf_Name:
;	.db $12,4
User_Text_14:
	.db $10,"Grf:",0

Num_98226:
	.db $00,$04,$fc,$98,$22,$60,$00,$00,$00,$00

.end